# UAV4Res Visualizer
 
## Install with PIP
```
pip install uav4res-visualizer
uav4res_visualizer
```
## Run with sourcecode
```
python -m uav4res_visualizer
```

# Reference
Theta*: https://arxiv.org/pdf/1401.3843 

A*: https://vi.wikipedia.org/wiki/Gi%E1%BA%A3i_thu%E1%BA%ADt_t%C3%ACm_ki%E1%BA%BFm_A*

BFS: https://wiki.vnoi.info/algo/graph-theory/breadth-first-search.md

Path planning system: https://ieeexplore.ieee.org/document/8955663
